@@ -3,7 +3,7 @@ def isMath(formula):
     return any(e in formula for e in CARACTERISTIC_SYMBOLS)
 
 def traceContainsSpellChecker(trace):
-    return any(e['module'] == 'spell-checker' for e in trace)
+    return any(e.module == 'spell-checker' for e in trace)
 
 def relevance(inputFormula, outputTree):
     lenOutput = len(str(outputTree))
